==> xcfa_3.4.1.orig.tar.gz: xcfa-3.4.1/src/win_norm_replay.c <==
 /*
 * file      : win_norm_replay.c
 * project   : xcfa
 * with      : Gtk-2
 *
 * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
 *
 * xcfa - GTK+ implementation of the GNU shell command
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


#include <gtk/gtk.h>
#include "support.h"
#include "global.h"
#include "utils.h"
#include "win_control.h"
#include "win_norm_replay.h"

/*
*--------------------------------------------------------------------------
* VARIABLES
*---------------------------------------------------------------------------
*/
typedef struct {
	GtkWidget       *Adr_Win;
	GtkWidget       *Adr_label_title;
	GtkWidget       *Adr_label_etat;
	GtkWidget       *Adr_label_compteur;
	GtkWidget       *Adr_ProgressBar;
	
	gboolean	 Bool_Is_Close;

} VAR_NORM_REPLAY;

VAR_NORM_REPLAY var_normreplay;

/*
*---------------------------------------------------------------------------
* REALIZE WINDOW
*---------------------------------------------------------------------------
*/
void on_label_titre_NormReplay_realize (GtkWidget *widget, gpointer user_data)
{
	var_normreplay.Adr_label_title = widget;
}
void on_label_etat_NormReplay_realize (GtkWidget *widget, gpointer user_data)
{
	var_normreplay.Adr_label_etat = widget;
}
void on_label_compteur_NormReplay_realize (GtkWidget *widget, gpointer user_data)
{
	var_normreplay.Adr_label_compteur = widget;
}
void on_progressbar_NormReplay_realize (GtkWidget *widget, gpointer user_data)
{
	var_normreplay.Adr_ProgressBar = widget;
}

/*
*---------------------------------------------------------------------------
* STOP USER
*---------------------------------------------------------------------------
*/
void on_button_stop_NormReplay_activate (GtkButton *button, gpointer user_data)
{
	var_normreplay.Bool_Is_Close = TRUE;
}

/*
*---------------------------------------------------------------------------
* END WIN
*---------------------------------------------------------------------------
*/
gboolean on_WinNormReplay_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
{
	var_normreplay.Bool_Is_Close = TRUE;
	return TRUE;
}
gboolean on_WinNormReplay_destroy_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
{
	var_normreplay.Bool_Is_Close = TRUE;
	return TRUE;
}

/*
*---------------------------------------------------------------------------
* CREATE WINDOW
*---------------------------------------------------------------------------
*/
void create_WinNormReplay (gchar *title)
{
  GtkWidget *WinNormReplay;
  GtkWidget *vbox42;
  GtkWidget *hbox138;
  GtkWidget *image182;
  GtkWidget *label_titre_NormReplay;
  GtkWidget *hseparator12;
  GtkWidget *vbox44;
  GtkWidget *label_etat_NormReplay;
  GtkWidget *hseparator16;
  GtkWidget *progressbar_NormReplay;
  GtkWidget *hseparator13;
  GtkWidget *hbox139;
  GtkWidget *button_stop_NormReplay;
  GtkWidget *alignment124;
  GtkWidget *hbox140;
  GtkWidget *image183;
  GtkWidget *label258;
  GtkWidget *label_compteur_NormReplay;
	gchar *Str = NULL;
	
	var_normreplay.Adr_Win =
	WinNormReplay = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_size_request (WinNormReplay, 400, -1);
  gtk_container_set_border_width (GTK_CONTAINER (WinNormReplay), 5);
  gtk_window_set_title (GTK_WINDOW (WinNormReplay), title);
  gtk_window_set_position (GTK_WINDOW (WinNormReplay), GTK_WIN_POS_CENTER);
  /*gtk_window_set_modal (GTK_WINDOW (WinNormReplay), TRUE);*/
  gtk_window_set_resizable (GTK_WINDOW (WinNormReplay), FALSE);

	wincontrol_set_adr (WinNormReplay, title, TRUE, TRUE);


  vbox42 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox42);
  gtk_container_add (GTK_CONTAINER (WinNormReplay), vbox42);

  hbox138 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox138);
  gtk_box_pack_start (GTK_BOX (vbox42), hbox138, FALSE, FALSE, 0);

  image182 = gtk_image_new_from_stock ("gtk-execute", GTK_ICON_SIZE_DIALOG);
  gtk_widget_show (image182);
  gtk_box_pack_start (GTK_BOX (hbox138), image182, FALSE, FALSE, 0);
	Str = g_strdup_printf ("<span font_desc=\"Courier bold 18\" >%s</span>", title);
  	label_titre_NormReplay = gtk_label_new (Str);
  	g_free (Str);
  	Str = NULL;
  gtk_widget_show (label_titre_NormReplay);
  gtk_box_pack_start (GTK_BOX (hbox138), label_titre_NormReplay, TRUE, TRUE, 0);
  gtk_widget_set_size_request (label_titre_NormReplay, -1, 19);
  gtk_label_set_use_markup (GTK_LABEL (label_titre_NormReplay), TRUE);

  hseparator12 = gtk_hseparator_new ();
  gtk_widget_show (hseparator12);
  gtk_box_pack_start (GTK_BOX (vbox42), hseparator12, FALSE, FALSE, 0);
  gtk_widget_set_size_request (hseparator12, -1, 10);

  vbox44 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox44);
  gtk_box_pack_start (GTK_BOX (vbox42), vbox44, TRUE, TRUE, 0);

  label_etat_NormReplay = gtk_label_new ("<b>Etat</b>");
  gtk_widget_show (label_etat_NormReplay);
  gtk_box_pack_start (GTK_BOX (vbox44), label_etat_NormReplay, FALSE, FALSE, 0);
  gtk_label_set_use_markup (GTK_LABEL (label_etat_NormReplay), TRUE);
	gtk_label_set_justify (GTK_LABEL (label_etat_NormReplay), GTK_JUSTIFY_LEFT);

  hseparator16 = gtk_hseparator_new ();
  gtk_widget_show (hseparator16);
  gtk_box_pack_start (GTK_BOX (vbox44), hseparator16, FALSE, FALSE, 0);
  gtk_widget_set_size_request (hseparator16, -1, 10);

  progressbar_NormReplay = gtk_progress_bar_new ();
  gtk_widget_show (progressbar_NormReplay);
  gtk_box_pack_start (GTK_BOX (vbox44), progressbar_NormReplay, FALSE, FALSE, 0);
  gtk_progress_bar_set_ellipsize (GTK_PROGRESS_BAR (progressbar_NormReplay), PANGO_ELLIPSIZE_START);

  hseparator13 = gtk_hseparator_new ();
  gtk_widget_show (hseparator13);
  gtk_box_pack_start (GTK_BOX (vbox42), hseparator13, FALSE, FALSE, 0);
  gtk_widget_set_size_request (hseparator13, -1, 10);

  hbox139 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox139);
  gtk_box_pack_start (GTK_BOX (vbox42), hbox139, FALSE, FALSE, 0);

  button_stop_NormReplay = gtk_button_new ();
  gtk_widget_show (button_stop_NormReplay);
  gtk_box_pack_start (GTK_BOX (hbox139), button_stop_NormReplay, FALSE, FALSE, 0);

  alignment124 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment124);
  gtk_container_add (GTK_CONTAINER (button_stop_NormReplay), alignment124);
	GTK_WIDGET_SET_FLAGS (button_stop_NormReplay, GTK_CAN_DEFAULT);

  hbox140 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox140);
  gtk_container_add (GTK_CONTAINER (alignment124), hbox140);

  image183 = gtk_image_new_from_stock ("gtk-stop", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image183);
  gtk_box_pack_start (GTK_BOX (hbox140), image183, FALSE, FALSE, 0);

  label258 = gtk_label_new_with_mnemonic ("Stop");
  gtk_widget_show (label258);
  gtk_box_pack_start (GTK_BOX (hbox140), label258, FALSE, FALSE, 0);

  label_compteur_NormReplay = gtk_label_new ("<b>Compteur: actuel / total</b>");
  gtk_widget_show (label_compteur_NormReplay);
  gtk_box_pack_start (GTK_BOX (hbox139), label_compteur_NormReplay, TRUE, TRUE, 0);
  gtk_label_set_use_markup (GTK_LABEL (label_compteur_NormReplay), TRUE);

  g_signal_connect ((gpointer) WinNormReplay, "delete_event", G_CALLBACK (on_WinNormReplay_delete_event), WinNormReplay);
  g_signal_connect ((gpointer) WinNormReplay, "destroy_event", G_CALLBACK (on_WinNormReplay_destroy_event), WinNormReplay);
  g_signal_connect ((gpointer) label_titre_NormReplay, "realize", G_CALLBACK (on_label_titre_NormReplay_realize), WinNormReplay);
  g_signal_connect ((gpointer) label_etat_NormReplay, "realize", G_CALLBACK (on_label_etat_NormReplay_realize), WinNormReplay);
  g_signal_connect ((gpointer) progressbar_NormReplay, "realize", G_CALLBACK (on_progressbar_NormReplay_realize), WinNormReplay);
  g_signal_connect ((gpointer) button_stop_NormReplay, "clicked", G_CALLBACK (on_button_stop_NormReplay_activate), WinNormReplay);
  g_signal_connect ((gpointer) label_compteur_NormReplay, "realize", G_CALLBACK (on_label_compteur_NormReplay_realize), WinNormReplay);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (WinNormReplay, WinNormReplay, "WinNormReplay");
  GLADE_HOOKUP_OBJECT (WinNormReplay, vbox42, "vbox42");
  GLADE_HOOKUP_OBJECT (WinNormReplay, hbox138, "hbox138");
  GLADE_HOOKUP_OBJECT (WinNormReplay, image182, "image182");
  GLADE_HOOKUP_OBJECT (WinNormReplay, label_titre_NormReplay, "label_titre_NormReplay");
  GLADE_HOOKUP_OBJECT (WinNormReplay, hseparator12, "hseparator12");
  GLADE_HOOKUP_OBJECT (WinNormReplay, vbox44, "vbox44");
  GLADE_HOOKUP_OBJECT (WinNormReplay, label_etat_NormReplay, "label_etat_NormReplay");
  GLADE_HOOKUP_OBJECT (WinNormReplay, hseparator16, "hseparator16");
  GLADE_HOOKUP_OBJECT (WinNormReplay, progressbar_NormReplay, "progressbar_NormReplay");
  GLADE_HOOKUP_OBJECT (WinNormReplay, hseparator13, "hseparator13");
  GLADE_HOOKUP_OBJECT (WinNormReplay, hbox139, "hbox139");
  GLADE_HOOKUP_OBJECT (WinNormReplay, button_stop_NormReplay, "button_stop_NormReplay");
  GLADE_HOOKUP_OBJECT (WinNormReplay, alignment124, "alignment124");
  GLADE_HOOKUP_OBJECT (WinNormReplay, hbox140, "hbox140");
  GLADE_HOOKUP_OBJECT (WinNormReplay, image183, "image183");
  GLADE_HOOKUP_OBJECT (WinNormReplay, label258, "label258");
  GLADE_HOOKUP_OBJECT (WinNormReplay, label_compteur_NormReplay, "label_compteur_NormReplay");

	gtk_widget_grab_default (button_stop_NormReplay);
	utils_set_default_icone_xcfa (WinNormReplay);
	gtk_widget_show_all (WinNormReplay);
}


/*
*---------------------------------------------------------------------------
* EXTERNAL
*---------------------------------------------------------------------------
*/

void WinNormReplay_close (void)
{
	var_normreplay.Bool_Is_Close = TRUE;
	gtk_widget_destroy(var_normreplay.Adr_Win);
}
gboolean WinNormReplay_is_get_close (void)
{
	return (var_normreplay.Bool_Is_Close);
}

void WinNormReplay_reset_progressBar (void)
{
	/* PRINT_FUNC_LF(); */
	gtk_widget_show (GTK_WIDGET (var_normreplay.Adr_ProgressBar));
	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (var_normreplay.Adr_ProgressBar), 0.0);
	gtk_progress_bar_set_text (GTK_PROGRESS_BAR (var_normreplay.Adr_ProgressBar), "Waiting ...");
}
void WinNormReplay_set_data_progressBar (double Etat)
{
	gchar     *Total= NULL;
	
	/* PRINT_FUNC_LF(); */

	if (Etat <= 0.0) Etat = 0.0;
	if (Etat >= 1.0) Etat = 1.0;
	
	Total = g_strdup_printf ("%d%%", (int)(Etat*100));
	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (var_normreplay.Adr_ProgressBar), Etat);
	gtk_progress_bar_set_text (GTK_PROGRESS_BAR (var_normreplay.Adr_ProgressBar), Total);
	g_free (Total);
	Total= NULL;
}

void WinNormReplay_set_etat (gchar *StrEtat)
{
	gtk_label_set_justify (GTK_LABEL (var_normreplay.Adr_label_etat), GTK_JUSTIFY_LEFT);
	gtk_label_set_markup (GTK_LABEL (var_normreplay.Adr_label_etat), StrEtat);
}

void WinNormReplay_set_compteur (gchar *StrCompteur)
{
	gtk_label_set_justify (GTK_LABEL (var_normreplay.Adr_label_compteur), GTK_JUSTIFY_LEFT);
	gtk_label_set_markup (GTK_LABEL (var_normreplay.Adr_label_compteur), StrCompteur);
}

void WinNormReplay_Create (gchar *title)
{
	var_normreplay.Bool_Is_Close = FALSE;
	create_WinNormReplay (title);
}

==> xcfa_3.4.9.orig.tar.gz: xcfa-3.4.9/src/win_norm_replay.c <==
 /*
 * file      : win_norm_replay.c
 * project   : xcfa
 * with      : Gtk-2
 *
 * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
 *
 * xcfa - GTK+ implementation of the GNU shell command
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


#include <gtk/gtk.h>
#include "callbacks.h"
#include "interface.h"
#include "support.h"
#include "global.h"
#include "utils.h"
#include "win_control.h"
#include "win_norm_replay.h"

/*
*--------------------------------------------------------------------------
* VARIABLES
*---------------------------------------------------------------------------
*/
typedef struct {
	GtkWidget       *Adr_Win;
	GtkWidget       *Adr_label_title;
	GtkWidget       *Adr_label_compteur;
	GtkWidget       *Adr_ProgressBar;
	
	gboolean	 Bool_Is_Close;

} VAR_NORM_REPLAY;

VAR_NORM_REPLAY var_normreplay;

/*
*---------------------------------------------------------------------------
* REALIZE WINDOW
*---------------------------------------------------------------------------
*/
void on_label_titre_wind_scan_realize (GtkWidget *widget, gpointer user_data)
{
	var_normreplay.Adr_label_title = widget;
}
void on_label_compteur_wind_scan_realize (GtkWidget *widget, gpointer user_data)
{
	var_normreplay.Adr_label_compteur = widget;
}
void on_progressbar_wind_scan_realize (GtkWidget *widget, gpointer user_data)
{
	var_normreplay.Adr_ProgressBar = widget;
}

/*
*---------------------------------------------------------------------------
* STOP USER
*---------------------------------------------------------------------------
*/
void on_button_cancel_wind_scan_clicked (GtkButton *button, gpointer user_data)
{
	var_normreplay.Bool_Is_Close = TRUE;
}

/*
*---------------------------------------------------------------------------
* END WIN
*---------------------------------------------------------------------------
*/
gboolean on_wind_scan_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
{
	var_normreplay.Bool_Is_Close = TRUE;
	return TRUE;
}
gboolean on_wind_scan_destroy_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
{
	var_normreplay.Bool_Is_Close = TRUE;
	return TRUE;
}

/*
*---------------------------------------------------------------------------
* CREATE WINDOW
*---------------------------------------------------------------------------
*/
void create_WinNormReplay (gchar *title)
{
	gchar	*Str = NULL;
	
	var_normreplay.Adr_Win = create_wind_scan ();
	wincontrol_set_adr (var_normreplay.Adr_Win, "var_normreplay.Adr_Win", TRUE, TRUE);
	
	utils_set_default_icone_xcfa (var_normreplay.Adr_Win);
	gtk_widget_show_all (var_normreplay.Adr_Win);

	Str = g_strdup_printf ("<span font_desc=\"sans 15\"><span color=\"black\"><b>%s</b></span></span>", title);
	gtk_label_set_markup (GTK_LABEL (var_normreplay.Adr_label_title), Str);
	g_free (Str);
	Str = NULL;
}


/*
*---------------------------------------------------------------------------
* EXTERNAL
*---------------------------------------------------------------------------
*/

void WinNormReplay_close (void)
{
	var_normreplay.Bool_Is_Close = TRUE;
	gtk_widget_destroy(var_normreplay.Adr_Win);
	wincontrol_remove_last ();
}
gboolean WinNormReplay_is_get_close (void)
{
	return (var_normreplay.Bool_Is_Close);
}

void WinNormReplay_reset_progressBar (void)
{
	/* PRINT_FUNC_LF(); */
	gtk_widget_show (GTK_WIDGET (var_normreplay.Adr_ProgressBar));
	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (var_normreplay.Adr_ProgressBar), 0.0);
	gtk_progress_bar_set_text (GTK_PROGRESS_BAR (var_normreplay.Adr_ProgressBar), "Waiting ...");
}
void WinNormReplay_set_data_progressBar (double Etat)
{
	gchar     *Total= NULL;
	
	/* PRINT_FUNC_LF(); */

	if (Etat <= 0.0) Etat = 0.0;
	if (Etat >= 1.0) Etat = 1.0;
	
	Total = g_strdup_printf ("%d%%", (int)(Etat*100));
	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (var_normreplay.Adr_ProgressBar), Etat);
	gtk_progress_bar_set_text (GTK_PROGRESS_BAR (var_normreplay.Adr_ProgressBar), Total);
	g_free (Total);
	Total= NULL;
}

void WinNormReplay_set_compteur (gchar *StrCompteur)
{
	gtk_label_set_justify (GTK_LABEL (var_normreplay.Adr_label_compteur), GTK_JUSTIFY_LEFT);
	gtk_label_set_markup (GTK_LABEL (var_normreplay.Adr_label_compteur), StrCompteur);
}

void WinNormReplay_Create (gchar *title)
{
	var_normreplay.Bool_Is_Close = FALSE;
	create_WinNormReplay (title);
}
